""" Boilerplate views for a Flask extension. """

import random
import string

from flask import Blueprint, render_template


# Use a randomly generated name in order to prevent name collision
# between this blueprint and that of the parent blueprint(s).
name = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(32))
name = 'FlaskWings_' + name
views = Blueprint(name, __name__)

@views.route('/')
def root():
    return render_template('index.html')

@views.route('/login')
def login():
    return render_template('login.html')



""" Boilerplate for a Flask extension class. """

import os 

import jinja2
from .views import views


class FlaskWings:
    """ Boilerplate Flask extension that overrides templates and views."""
    
    def __init__(self, app):
        """ Add the default templates directory and default views
        to the parent application.
        """
        templates_dir = os.path.join(
            os.path.dirname(os.path.realpath(__file__)), 'templates')
        my_loader = jinja2.ChoiceLoader([
            app.jinja_loader,
            jinja2.FileSystemLoader(templates_dir),
        ])
        app.jinja_loader = my_loader
        app.register_blueprint(views)



import os
from setuptools import setup

exec(open('./flask_wings/version.py').read())

with open('README.rst') as f:
    long_description = f.read()
    
setup(
    name='Flask-Wings',
    version=__version__,
    url='http://github.com/vmlaker/flask-wings',
    license='MIT',
    author='Velimir Mlaker',
    author_email='vel.i.mir.mlaker@gmail.com',
    description='Boilerplate Flask extension.',
    long_description=long_description,
    packages=['flask_wings'],
    package_data={'flask_wings': ['templates/*']},
    include_package_data=True,
    platforms='any',
    zip_safe=False,
    setup_requires=[
        'pytest-runner==4.2',
    ],
    tests_require=[
        'pytest==3.7.4',
    ],
    install_requires=[
        'Flask==1.0.2'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Flask',
    ]
)
